pub struct SimpleModel<T = f64> {
pub config: StandardModelConfig<T>,
pub features: ModelFeatures,
pub params: ModelParams<T>,
}Fields
config: StandardModelConfig<T>features: ModelFeaturesparams: ModelParams<T>Implementations
Sourceimpl<T> SimpleModel<T>
impl<T> SimpleModel<T>
pub fn new(config: StandardModelConfig<T>, features: ModelFeatures) -> Self
Sourcepub const fn config(&self) -> &StandardModelConfig<T>
pub const fn config(&self) -> &StandardModelConfig<T>
returns a reference to the model configuration
Sourcepub const fn config_mut(&mut self) -> &mut StandardModelConfig<T>
pub const fn config_mut(&mut self) -> &mut StandardModelConfig<T>
returns a mutable reference to the model configuration
Sourcepub const fn features(&self) -> ModelFeatures
pub const fn features(&self) -> ModelFeatures
returns the model features
Sourcepub const fn features_mut(&mut self) -> &mut ModelFeatures
pub const fn features_mut(&mut self) -> &mut ModelFeatures
returns a mutable reference to the model features
Sourcepub const fn params(&self) -> &ModelParams<T>
pub const fn params(&self) -> &ModelParams<T>
returns a reference to the model parameters
Sourcepub const fn params_mut(&mut self) -> &mut ModelParams<T>
pub const fn params_mut(&mut self) -> &mut ModelParams<T>
returns a mutable reference to the model parameters
Sourcepub fn set_config(&mut self, config: StandardModelConfig<T>) -> &mut Self
pub fn set_config(&mut self, config: StandardModelConfig<T>) -> &mut Self
set the current configuration and return a mutable reference to the model
Sourcepub fn set_features(&mut self, features: ModelFeatures) -> &mut Self
pub fn set_features(&mut self, features: ModelFeatures) -> &mut Self
set the current features and return a mutable reference to the model
Sourcepub fn set_params(&mut self, params: ModelParams<T>) -> &mut Self
pub fn set_params(&mut self, params: ModelParams<T>) -> &mut Self
set the current parameters and return a mutable reference to the model
Sourcepub fn with_config(self, config: StandardModelConfig<T>) -> Self
pub fn with_config(self, config: StandardModelConfig<T>) -> Self
consumes the current instance to create another with the given configuration
Sourcepub fn with_features(self, features: ModelFeatures) -> Self
pub fn with_features(self, features: ModelFeatures) -> Self
consumes the current instance to create another with the given features
Sourcepub fn with_params(self, params: ModelParams<T>) -> Self
pub fn with_params(self, params: ModelParams<T>) -> Self
consumes the current instance to create another with the given parameters